<?php 
require_once __DIR__.'/maincore.php';
require_once THEMES.'templates/header.php';
add_to_title('Kalkulator Kalorii- Obliczaj Kalorie w Posiłkach i Dostosuj Dietę do Swoich Potrzeb'); 
set_meta("description", "Kalkulator Kalorii to wtyczka dla PHP Fusion, która pozwala na łatwe obliczenie ilości kalorii w posiłkach. Idealne narzędzie dla sportowców, osób pracujących fizycznie oraz tych, którzy chcą schudnąć, dostosowując dietę do indywidualnych potrzeb kalorycznych.");
add_to_head('<style> body{font-family:Arial, sans-serif;background-color:#f9f9f9;padding:20px;}h1{color:#333;font-size:2.5em;margin-bottom:20px;text-align:center;font-weight:bold;}h2{color:#555;font-size:1.5em;margin:20px 0 10px;}.container{background-color:#fff;padding:20px;border-radius:5px;box-shadow:0 2px 5px rgba(0, 0, 0, 0.1);margin-bottom:20px;}.article-item{width:90%;overflow:hidden;margin:auto;}.article-item h1{font-size:1.5em;color:#333;font-weight:bold;}.article-article{max-width:95%;margin:auto;font-size:22px;color:#333;}.form-container{max-width:33.33%;margin:0 auto;}.radio input[type="radio"]{width:20px;height:20px;margin-right:10px;}.nutrient{margin:10px 0;padding:10px;background-color:#e9ecef;border-left:5px solid #007bff;}.form-group{margin-bottom:15px;}.btn-primary{background-color:#007bff;border-color:#007bff;}.btn-primary:hover{background-color:#0056b3;border-color:#0056b3;}@media (max-width:768px){body{padding:10px;}h1{font-size:1.8em;}h2{font-size:1.3em;}.container{padding:15px;}.article-item h1{font-size:1.6em;}.article-article{font-size:18px;}}.calories-result{color:#007bff;}</style>');

$total_calories = 0;

// Kalorie na 100g dla konkretnych produktów
$calories_per_100g = [
    // Mięso
    'Mięso' => [
        'Kurczak' => 250,
        'Wołowina' => 300,
        'Wieprzowina' => 250,
        'Indyk' => 200,
        'Jagnięcina' => 250
    ],
    
    // Warzywa
    'Warzywa' => [
        'Marchew' => 41,
        'Brokuł' => 34,
        'Ziemniak' => 77,
        'Papryka' => 20,
        'Cebula' => 40
    ],
    
    // Owoce
    'Owoce' => [
        'Jabłko' => 52,
        'Banana' => 89,
        'Pomarańcza' => 47,
        'Truskawka' => 32,
        'Winogrona' => 69
    ],
    
    // Pieczywo
    'Pieczywo' => [
        'Chleb pszenny' => 265,
        'Chleb żytni' => 250,
        'Bułka' => 270,
        'Bagietka' => 270
    ],
    
    // Ryż i kasze
    'Ryż i kasze' => [
        'Ryż biały' => 130,
        'Ryż brązowy' => 111,
        'Kasza gryczana' => 343,
        'Kasza jęczmienna' => 352,
        'Kasza kuskus' => 376
    ],
    
    // Ryby
    'Ryby' => [
        'Łosoś' => 206,
        'Tuńczyk' => 132,
        'Dorsz' => 105,
        'Sielawa' => 140
    ]
];

if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $product_names = $_POST['product_name'];
    $product_weights = $_POST['product_weight'];

    for ($i = 0; $i < count($product_names); $i++) {
        $name = $product_names[$i];
        $weight = $product_weights[$i];

        // Sprawdzenie, w której kategorii znajduje się produkt
        foreach ($calories_per_100g as $category => $products) {
            if (isset($products[$name])) {
                $calories = ($products[$name] / 100) * $weight;
                $total_calories += $calories;
                break; // Przerwij pętlę, gdy znajdziesz produkt
            }
        }
    }
}
?>

<h1 class="text-center text-primary">Kalkulator Kalorii</h1>
<div class="container">
<form action="" method="post">
    <div id="products">
        <div class="product">
            <label for="product_name[]">Nazwa produktu:</label>
            <select name="product_name[]" required>
                <option value="">Wybierz produkt</option>
                <?php foreach ($calories_per_100g as $category => $products): ?>
                    <?php foreach ($products as $product => $calories): ?>
                        <option value="<?php echo $product; ?>"><?php echo $product; ?></option>
                    <?php endforeach; ?>
                <?php endforeach; ?>
            </select>
            
            <label for="product_weight[]">Waga (g):</label>
            <input type="number" name="product_weight[]" required>
        </div>
    </div>
    <button type="button" class="btn btn-primary" onclick="addProduct()">Dodaj produkt</button>
<br><br>
<input type="submit" class="btn btn-success" value="Oblicz kalorie">
<input type="reset" class="btn btn-warning" value="Resetuj formularz">


</form> 

<?php if ($_SERVER["REQUEST_METHOD"] == "POST"): ?>
    <h1 class="calories-result">Łączna liczba kalorii: <?php echo round($total_calories, 2); ?> kcal</h1>
<?php endif; ?>
<section>
            <p>Obliczenie zapotrzebowania kalorycznego jest kluczowe dla utrzymania zdrowej diety i stylu życia. Istnieją różne metody obliczania, ale jedną z najpopularniejszych jest wyliczenie podstawowej przemiany materii (PPM).</p>
            <h2>Wzory do obliczeń</h2>
            <p>Dla mężczyzn, wzór na PPM wygląda następująco:</p>
            <pre>
                PPM [kcal] = (10 × masa ciała w kg) + (6,25 × wzrost w cm) – (5 × wiek w latach) + 5
            </pre>
            <p>Dla kobiet, wzór jest nieco inny:</p>
            <pre>
                PPM [kcal] = (10 × masa ciała w kg) + (6,25 × wzrost w cm) – (5 × wiek w latach) – 161
            </pre>
            <p>Znając swoją PPM, można lepiej dostosować dietę do indywidualnych potrzeb energetycznych.</p>
        </section>
        
        <h2>Dlaczego warto korzystać z kalkulatora kalorii?</h2>
        <p>
            Wiedza na temat ilości kalorii w spożywanych produktach jest kluczowa dla utrzymania zdrowej diety. 
            Kalkulator Kalorii pozwala na łatwe i szybkie obliczenie wartości energetycznej posiłków, co może pomóc w planowaniu diety oraz osiąganiu celów zdrowotnych.
        </p>
    </div>

<script>
    function addProduct() {
        const productsDiv = document.getElementById('products');
        const newProductDiv = document.createElement('div');
        newProductDiv.classList.add('product');
        newProductDiv.innerHTML = `
            <label for="product_name[]">Nazwa produktu:</label>
            <select name="product_name[]" required>
                <option value="">Wybierz produkt</option>
                <?php foreach ($calories_per_100g as $category => $products): ?>
                    <?php foreach ($products as $product => $calories): ?>
                        <option value="<?php echo $product; ?>"><?php echo $product; ?></option>
                    <?php endforeach; ?>
                <?php endforeach; ?>
            </select>
            
            <label for="product_weight[]">Waga (g):</label>
            <input type="number" name="product_weight[]" required>
        `;
        productsDiv.appendChild(newProductDiv);
    }
</script>
<?php
require_once THEMES.'templates/footer.php';
?>
